import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {UserService} from '../../../services/user.service';
import {NzMessageService} from 'ng-zorro-antd';

@Component({
  selector: 'app-user-list',
  templateUrl: './user-list.component.html',
  styleUrls: ['./user-list.component.scss']
})
export class UserListComponent implements OnInit {

  searchForm: FormGroup; // 搜索框
  requestData = []; // 列表数据
  total: number; // 页码
  pageNum = 1; // 页码
  pageSize = 10; // 条码
  loading = true;
  regTime;
  constructor(
      private form: FormBuilder,
      private user: UserService,
      private message: NzMessageService
  ) { }

  ngOnInit(): void {
    this.init();
  }

  public init(): void {
    this.searchForm = this.form.group({
      name: [null],
      phone: [null],
      regTime: [null],
    });
    this.getRequest(true , this.searchForm.value);
  }

  // 查询列表
  public getRequest(reset: boolean = false , whereObject: object) {

    if (whereObject['regTime'] != null && whereObject['regTime'].length !== 0) {
       whereObject['regTimeStart'] = whereObject['regTime'][0];
       whereObject['regTimeEnd'] = whereObject['regTime'][1];
    }
    this.loading = false;
    if (reset) {
      this.pageNum = 1;
    }
    whereObject['pageNum'] = this.pageNum;
    whereObject['pageSize'] = this.pageSize;
    this.user.getListUser( whereObject, data => {
      console.log(data);
      if (data['return_code'] === '000000') {
        this.requestData = data['return_data'].list;
        this.total = data['return_data'].total;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 重置
  public resetForm(): void {
    this.searchForm.reset();
  }

}
